@@ -6,11 +6,12 @@ use warnings;
 use Log::ger;
 
 use Perinci::Exporter;
+use Perinci::Object;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-09-20'; # DATE
+our $DATE = '2022-09-21'; # DATE
 our $DIST = 'App-FfmpegUtils'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 our %SPEC;
 
@@ -19,7 +20,7 @@ $SPEC{':package'} = {
     summary => 'Utilities related to ffmpeg',
 };
 
-our %arg0_file = (
+our %argspec0_file = (
     file => {
         schema => 'filename*',
         req => 1,
@@ -27,7 +28,7 @@ our %arg0_file = (
     },
 );
 
-our %arg0_files = (
+our %argspec0_files = (
     files => {
         'x.name.is_plural' => 1,
         'x.name.singular' => 'file',
@@ -38,12 +39,19 @@ our %arg0_files = (
     },
 );
 
-our %argopt_ffmpeg_path = (
+our %argspecopt_ffmpeg_path = (
     ffmpeg_path => {
         schema => 'filename*',
     },
 );
 
+our %argspecopt_copy = (
+    copy => {
+        summary => 'Whether to use the "copy" codec (fast but produces inaccurate timings)',
+        schema => 'bool*',
+    },
+);
+
 my @presets = qw/ultrafast superfast veryfast faster fast medium slow slower veryslow/;
 
 sub _nearest {
@@ -91,8 +99,8 @@ or (if downsizing is done):
 
 _
     args => {
-        %arg0_files,
-        %argopt_ffmpeg_path,
+        %argspec0_files,
+        %argspecopt_ffmpeg_path,
         crf => {
             schema => ['int*', between=>[0,51]],
         },
@@ -268,23 +276,15 @@ you will have 5 new video files: `long.1of5.mp4` (15min), `long.2of5.mp4`
 (15min), `long.3of5.mp4` (15min), `long.4of5.mp4` (15min), and `long.5of5.mp4`
 (12min).
 
-Currently this utility uses `-c copy` ffmpeg option, so there might be a few of
-seconds of glitches around the cut points. An option to use other codec will be
-provided in the future.
-
 _
     args => {
-        %arg0_file,
+        %argspec0_files,
         # XXX start => {},
         every => {
             schema => 'duration*',
             req => 1,
-            pos => 1,
-        },
-        copy => {
-            summary => 'Whether to use the "copy" codec (fast but produces inaccurate timings)',
-            schema => 'bool*',
         },
+        %argspecopt_copy,
         # XXX merge_if_last_part_is_shorter_than => {},
         # XXX output_filename_pattern
     },
@@ -296,6 +296,13 @@ _
             test => 0,
             'x.doc.show_result' => 0,
         },
+        {
+            summary => 'Split video per 30s for WhatsApp status',
+            src_plang => 'bash',
+            src => '[[prog]] foo.mp4 30s',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
     ],
     features => {
         dry_run => 1,
@@ -311,33 +318,58 @@ sub split_video_by_duration {
     require POSIX;
 
     my %args = @_;
-    my $file = $args{file};
+    my $files = $args{files};
     my $part_dur = $args{every};
     $part_dur > 0 or return [400, "Please specify a non-zero --every"];
 
-    require Media::Info;
-    my $res = Media::Info::get_media_info(media => $file);
-    return $res unless $res->[0] == 200;
+    my $envres = envresmulti();
+    my $j = -1;
+    for my $file (@$files) {
 
-    my $total_dur = $res->[2]{duration}
-        or return [412, "Duration of video is zero"];
+        $j++;
+        log_info "Processing file %s ...", $file;
 
-    my $num_parts = POSIX::ceil($total_dur / $part_dur);
-    my $fmt = $num_parts >= 1000 ? "%04d" : $num_parts >= 100 ? "%03d" : $num_parts >= 10 ? "%02d" : "%d";
+        require Media::Info;
+        my $res = Media::Info::get_media_info(media => $file);
+        unless ($res->[0] == 200) {
+            $envres->add_result($res->[0], "Can't get info for video $file: $res->[1]", {item_id=>$j});
+            next;
+        }
 
-    return [304, "No split necessary"] if $num_parts < 2;
+        my $total_dur = $res->[2]{duration};
+        unless ($total_dur) {
+            $envres->add_result(412, "Duration of video $file is zero", {item_id=>$j});
+            next;
+        }
 
-    require IPC::System::Options;
-    for my $i (1..$num_parts) {
-        my $part_label = sprintf "${fmt}of%d", $i, $num_parts;
-        my $ofile = $file;
-        if ($ofile =~ /\.\w+\z/) { $ofile =~ s/(\.\w+)\z/.$part_label$1/ } else { $ofile .= ".$part_label" }
-        my $time_start = ($i-1)*$part_dur;
-        IPC::System::Options::system(
-            {log=>1, dry_run=>$args{-dry_run}},
-            "ffmpeg", "-i", $file, ($args{copy} ? ("-c", "copy") : ()), "-ss", $time_start, "-t", $part_dur, $ofile);
-    }
-    [200];
+        my $num_parts = POSIX::ceil($total_dur / $part_dur);
+        my $fmt = $num_parts >= 1000 ? "%04d" : $num_parts >= 100 ? "%03d" : $num_parts >= 10 ? "%02d" : "%d";
+
+        unless ($num_parts >= 2) {
+            $envres->add_result(304, "No split necessary for video $file", {item_id=>$j});
+            next;
+        }
+
+        require IPC::System::Options;
+        for my $i (1..$num_parts) {
+            my $part_label = sprintf "${fmt}of%d", $i, $num_parts;
+            my $ofile = $file;
+            if ($ofile =~ /\.\w+\z/) { $ofile =~ s/(\.\w+)\z/.$part_label$1/ } else { $ofile .= ".$part_label" }
+            my $time_start = ($i-1)*$part_dur;
+            IPC::System::Options::system(
+                {log=>1, dry_run=>$args{-dry_run}},
+                "ffmpeg", "-i", $file, ($args{copy} ? ("-c", "copy") : ()), "-ss", $time_start, "-t", $part_dur, $ofile);
+            my ($exit_code, $signal, $core_dump) = ($? < 0 ? $? : $? >> 8, $? & 127, $? & 128);
+            if ($exit_code) {
+                $envres->add_result(500, "ffmpeg exited $exit_code (sig $signal) for video $file: $!", {item_id=>$j});
+            } else {
+                $envres->add_result(200, "Video $file successfully split", {item_id=>$j});
+            }
+        }
+
+    } # for $file
+
+    $envres->as_struct;
 }
 
 $SPEC{cut_video_by_duration} = {
@@ -352,7 +384,7 @@ duration. It automatically chooses a filename if you don't specify one.
 
 _
     args => {
-        %arg0_file,
+        %argspec0_file,
         start => {
             schema => 'duration*',
             req => 1,
@@ -419,7 +451,7 @@ App::FfmpegUtils - Utilities related to ffmpeg
 
 =head1 VERSION
 
-This document describes version 0.010 of App::FfmpegUtils (from Perl distribution App-FfmpegUtils), released on 2022-09-20.
+This document describes version 0.011 of App::FfmpegUtils (from Perl distribution App-FfmpegUtils), released on 2022-09-21.
 
 =head1 FUNCTIONS
 
@@ -596,10 +628,6 @@ you will have 5 new video files: C<long.1of5.mp4> (15min), C<long.2of5.mp4>
 (15min), C<long.3of5.mp4> (15min), C<long.4of5.mp4> (15min), and C<long.5of5.mp4>
 (12min).
 
-Currently this utility uses C<-c copy> ffmpeg option, so there might be a few of
-seconds of glitches around the cut points. An option to use other codec will be
-provided in the future.
-
 This function is not exported.
 
 This function supports dry-run operation.
@@ -615,7 +643,7 @@ Whether to use the "copy" codec (fast but produces inaccurate timings).
 
 =item * B<every>* => I<duration>
 
-=item * B<file>* => I<filename>
+=item * B<files>* => I<array[filename]>
 
 
 =back
